@@ -143,8 +143,8 @@ class Stats(models.Model):
                     "balance": char_level[c]["bal"],
                 }
             )
-            self.admin_char_json = char_data
-            self.save()
+        self.admin_char_json = char_data
+        self.save()
 
     def get_admin_char_json(self):
         if self.admin_char_json is None:
@@ -193,7 +193,7 @@ class Stats(models.Model):
                 f"href='{summary_url}'>"
                 '<i class="fas fa-search"></i></a>'
                 '<button type="button" class="btn btn-primary btn-sm" '
-                'data-toggle="modal" data-target="#modalCredit" '
+                'data-bs-toggle="modal" data-bs-target="#modalCredit" '
                 f'onClick="populate({i})" >'
                 "$$</button>"
             )
@@ -224,7 +224,6 @@ class Stats(models.Model):
         return self.admin_main_json
 
     def calc_ore_prices_json(self):
-        settings = Settings.load()
         data = []
         pg = PriceGroups()
         for ore in OrePrices.objects.all():
@@ -236,7 +235,7 @@ class Stats(models.Model):
             refined = 1000.0 * ore.refined_price
             taxed = 1000.0 * ore.taxed_price
             group = "tax_" + pg.taxgroups[ore.eve_type.eve_group_id]
-            tax_rate = settings.__dict__[group] / 100.0
+            tax_rate = ore.tax_rate / 100.0
 
             tax = taxed * tax_rate
             remaining = taxed - tax
@@ -315,9 +314,10 @@ class Stats(models.Model):
         return self.admin_get_all_activity_json
 
     def calc_admin_mining_by_sys_json(self):
-        entries = CharacterMiningLedgerEntry.objects.all().prefetch_related(
-            "character", "eve_type", "eve_solar_system"
-        )
+        days_90 = now() - dt.timedelta(days=90)
+        entries = CharacterMiningLedgerEntry.objects.filter(
+            date__gte=days_90
+        ).prefetch_related("character", "eve_type", "eve_solar_system")
         sys = {}
         pg = PriceGroups()
         allgroups = set()
@@ -548,8 +548,8 @@ class Stats(models.Model):
         return self.admin_corp_ledger
 
     def calc_admin_corp_mining_history(self):
-        days_90 = now() - dt.timedelta(days=90)
-        obs = AdminMiningObsLog.objects.filter(date__gte=days_90).order_by("-date")
+        days_3month = now().date() + relativedelta(months=-3)
+        obs = AdminMiningObsLog.objects.filter(date__gte=days_3month).order_by("-date")
         cache = {}
         data = []
         unknown_chars = {}
@@ -669,6 +669,7 @@ class Stats(models.Model):
         curmonth = dt.date(now().year, now().month, 1)
         found = None
         linegraph = {}
+        first, last = None, None
         for d in lb["data"]:
             if d["month"] == str(curmonth):
                 found = d["table"]
@@ -678,9 +679,14 @@ class Stats(models.Model):
                 for cpk in lb["mains"][d["character"]]:
                     c = Character.objects.get(pk=cpk)
                     for dm in c.get_curmonth_daily_mining():
-                        if str(dm.date) not in linegraph[d["character"]]:
-                            linegraph[d["character"]][str(dm.date)] = 0
-                        linegraph[d["character"]][str(dm.date)] += dm.taxed_value
+                        dmdate = str(dm.date)
+                        if dmdate not in linegraph[d["character"]]:
+                            linegraph[d["character"]][dmdate] = 0
+                        linegraph[d["character"]][dmdate] += dm.taxed_value
+                        if first is None or first > dmdate:
+                            first = dmdate
+                        if last is None or last < dmdate:
+                            last = dmdate
         for c in linegraph.keys():
             final = []
             cumisk = 0
@@ -688,6 +694,13 @@ class Stats(models.Model):
                 cumisk += isk
                 final.append({"date": d, "value": cumisk})
             linegraph[c] = final
+
+        for k in linegraph.keys():
+            if linegraph[k][0]["date"] != first:
+                linegraph[k].insert(0, {"date": first, "value": 0})
+            if linegraph[k][-1]["date"] != last:
+                linegraph[k].append({"date": last, "value": linegraph[k][-1]["value"]})
+
         self.curmonth_leadergraph = {"data": linegraph}
         self.save()
 
@@ -712,6 +725,8 @@ class Stats(models.Model):
             user2chars[c.user].append(c)
 
         for user, characters in user2chars.items():
+            if user is None:
+                continue
             allpgs = {}
             alldays = {}
             polar = {}
