@@ -157,9 +157,26 @@ def auto_add_chars(self):
             continue
         # check if orphaned and find user
         try:
-            u = char.userprofile
+            u = char.character_ownership.user.profile
         except EveCharacter.userprofile.RelatedObjectDoesNotExist:
             continue
+
+        # check to see if MemberAudit is installed and if the character has entries in the mining ledger.
+        detectedLedger = None
+        try:
+            from memberaudit.models import Character as maCharacter
+
+            machar = maCharacter.objects.get(eve_character=char)
+            num_ledger = len(machar.mining_ledger.all())
+            detectedLedger = False
+            if num_ledger > 0:
+                detectedLedger = True
+        except Exception:
+            pass
+
+        if detectedLedger is not None and not detectedLedger:
+            continue
+
         logger.info(f"Need to add {char} to miningtaxes, user: {u}")
         with transaction.atomic():
             mcharacter, _ = Character.objects.update_or_create(eve_character=char)
@@ -468,6 +485,8 @@ def add_tax_credits():
                 pass
             except Http404:
                 continue
+            except EveCharacter.DoesNotExist:
+                continue
             payee.tax_credits.update_or_create(
                 date=entry.date, credit=entry.amount, defaults={"credit_type": "paid"}
             )
@@ -496,23 +515,32 @@ def add_corp_moon_taxes_by_char(character):
     entries = AdminMiningObsLog.objects.filter(
         miner_id=character.eve_character.character_id
     )
+    consolidate = {}
     for entry in entries:
+        k = f"{entry.date}\t{entry.eve_solar_system_id}\t{entry.eve_type_id}"
+        if k not in consolidate:
+            consolidate[k] = 0
+        consolidate[k] += entry.quantity
+
+    for k in consolidate.keys():
+        (edate, esys, etype) = k.split("\t")
+        equantity = consolidate[k]
         try:
             row = character.mining_ledger.get(
-                date=entry.date,
-                eve_solar_system=entry.eve_solar_system,
-                eve_type=entry.eve_type,
+                date=edate,
+                eve_solar_system_id=esys,
+                eve_type_id=etype,
             )
-            if row.quantity != entry.quantity:
-                row.quantity = entry.quantity
+            if row.quantity != equantity:
+                row.quantity = equantity
                 row.save()
                 row.calc_prices()
         except CharacterMiningLedgerEntry.DoesNotExist:
             row = character.mining_ledger.create(
-                date=entry.date,
-                eve_solar_system=entry.eve_solar_system,
-                eve_type=entry.eve_type,
-                quantity=entry.quantity,
+                date=edate,
+                eve_solar_system_id=esys,
+                eve_type_id=etype,
+                quantity=equantity,
             )
             row.calc_prices()
 
